# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ..v0 import causality_pb2 as _causality_pb2
from ..v0 import participant_transaction_pb2 as _participant_transaction_pb2
from ..v0 import synchronization_pb2 as _synchronization_pb2
from ..v0 import topology_pb2 as _topology_pb2
from . import participant_transaction_pb2 as _participant_transaction_pb2_1
from . import participant_transfer_pb2 as _participant_transfer_pb2
from . import topology_pb2 as _topology_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EnvelopeContent(_message.Message):
    __slots__ = ("informee_message", "signed_message", "encrypted_view_message", "domain_topology_transaction_message", "transfer_out_mediator_message", "transfer_in_mediator_message", "root_hash_message", "register_topology_transaction_request", "register_topology_transaction_response", "causality_message")
    INFORMEE_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SIGNED_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_VIEW_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_TOPOLOGY_TRANSACTION_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_OUT_MEDIATOR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_IN_MEDIATOR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    REGISTER_TOPOLOGY_TRANSACTION_REQUEST_FIELD_NUMBER: _ClassVar[int]
    REGISTER_TOPOLOGY_TRANSACTION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    CAUSALITY_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    informee_message: _participant_transaction_pb2_1.InformeeMessage
    signed_message: _synchronization_pb2.SignedProtocolMessage
    encrypted_view_message: _participant_transaction_pb2_1.EncryptedViewMessage
    domain_topology_transaction_message: _topology_pb2.DomainTopologyTransactionMessage
    transfer_out_mediator_message: _participant_transfer_pb2.TransferOutMediatorMessage
    transfer_in_mediator_message: _participant_transfer_pb2.TransferInMediatorMessage
    root_hash_message: _participant_transaction_pb2.RootHashMessage
    register_topology_transaction_request: _topology_pb2.RegisterTopologyTransactionRequest
    register_topology_transaction_response: _topology_pb2_1.RegisterTopologyTransactionResponse
    causality_message: _causality_pb2.CausalityMessage
    def __init__(self, informee_message: _Optional[_Union[_participant_transaction_pb2_1.InformeeMessage, _Mapping]] = ..., signed_message: _Optional[_Union[_synchronization_pb2.SignedProtocolMessage, _Mapping]] = ..., encrypted_view_message: _Optional[_Union[_participant_transaction_pb2_1.EncryptedViewMessage, _Mapping]] = ..., domain_topology_transaction_message: _Optional[_Union[_topology_pb2.DomainTopologyTransactionMessage, _Mapping]] = ..., transfer_out_mediator_message: _Optional[_Union[_participant_transfer_pb2.TransferOutMediatorMessage, _Mapping]] = ..., transfer_in_mediator_message: _Optional[_Union[_participant_transfer_pb2.TransferInMediatorMessage, _Mapping]] = ..., root_hash_message: _Optional[_Union[_participant_transaction_pb2.RootHashMessage, _Mapping]] = ..., register_topology_transaction_request: _Optional[_Union[_topology_pb2.RegisterTopologyTransactionRequest, _Mapping]] = ..., register_topology_transaction_response: _Optional[_Union[_topology_pb2_1.RegisterTopologyTransactionResponse, _Mapping]] = ..., causality_message: _Optional[_Union[_causality_pb2.CausalityMessage, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .mediator_pb2 import TransactionResultMessage, TransferResult, Verdict
from .participant_transaction_pb2 import ActionDescription, ViewParticipantData
from .synchronization_pb2 import EnvelopeContent

__all__ = [
    "ActionDescription",
    "EnvelopeContent",
    "TransactionResultMessage",
    "TransferResult",
    "Verdict",
    "ViewParticipantData",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v0 import sequencing_pb2 as _sequencing_pb2
from . import common_pb2 as _common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransferInView(_message.Message):
    __slots__ = ("salt", "submitter", "contract", "transfer_out_result_event", "creating_transaction_id", "source_protocol_version")
    SALT_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_OUT_RESULT_EVENT_FIELD_NUMBER: _ClassVar[int]
    CREATING_TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    submitter: str
    contract: _common_pb2.SerializableContract
    transfer_out_result_event: _sequencing_pb2.SignedContent
    creating_transaction_id: bytes
    source_protocol_version: int
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., submitter: _Optional[str] = ..., contract: _Optional[_Union[_common_pb2.SerializableContract, _Mapping]] = ..., transfer_out_result_event: _Optional[_Union[_sequencing_pb2.SignedContent, _Mapping]] = ..., creating_transaction_id: _Optional[bytes] = ..., source_protocol_version: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from contextlib import ExitStack
from datetime import datetime
import logging
from os import PathLike
from pathlib import Path
from subprocess import Popen, TimeoutExpired
import sys
from threading import Event, Thread
import time
from typing import Optional

from google.protobuf.empty_pb2 import Empty
from grpc import insecure_channel, secure_channel, ssl_channel_credentials

from .._gen.com.digitalasset.canton.health.admin.v0.status_service_pb2_grpc import StatusServiceStub
from ..prim import DazlError, TimeDeltaLike, to_timedelta

__all__ = ["kill_process_tree", "wait_for_process_port", "ProcessLogger", "ProcessDiedException"]


def kill_process_tree(process: Popen):
    """
    Kill a process and its children.
    """
    #
    # noinspection PyBroadException
    try:
        # noinspection PyPackageRequirements,PyUnresolvedReferences
        import psutil

        children = psutil.Process(pid=process.pid).children()
    except:  # noqa
        children = []

    process.terminate()
    try:
        # give the process a few seconds to die
        process.communicate(timeout=5)

    except TimeoutExpired:
        logging.error("Had trouble killing a sandbox process normally; it will be forcibly killed.")
        # if there are child processes, start working around the parent process and try to
        # terminate them directly
        #
        # noinspection PyBroadException
        for child in children:
            try:
                child.kill()
            except:  # noqa
                pass

        process.kill()
        process.communicate()


def wait_for_process_port(
    process: Popen,
    port: int,
    timeout: TimeDeltaLike,
    *,
    participant_admin_port: Optional[int] = None,
    participant_admin_cert_file: Optional[PathLike] = None,
) -> None:
    from .io import is_port_alive

    alive = False
    max_time_wait = datetime.utcnow() + to_timedelta(timeout)

    logging.debug("Waiting for port %s to be alive on pid %s...", port, process.pid)
    while (
        (max_time_wait is None or (datetime.utcnow() < max_time_wait))
        and process.poll() is None
        and not alive
    ):
        alive = is_port_alive(port)
        if alive:
            # additionally check for an active participant_admin_port and only do a status check
            # if that port is open
            if participant_admin_port is not None and is_port_alive(participant_admin_port):
                logging.debug("Waiting for the participant to report itself as active...")
                with ExitStack() as stack:
                    if participant_admin_cert_file is not None:
                        credentials = ssl_channel_credentials(
                            root_certificates=Path(participant_admin_cert_file).read_bytes()
                        )
                        channel = stack.enter_context(
                            secure_channel(f"localhost:{participant_admin_port}", credentials)
                        )
                    else:
                        channel = stack.enter_context(
                            insecure_channel(f"localhost:{participant_admin_port}")
                        )
                    status_service = StatusServiceStub(channel)
                    response = status_service.Status(Empty())
                    alive = response.success.active

                if not alive:
                    time.sleep(0.5)

    if not alive:
        return_code = process.returncode
        if return_code is not None:
            raise ProcessDiedException(return_code, "The process exited with an error code")
        raise Exception("Timed out while waiting for a process to start")


class ProcessLogger:
    """
    Pipe stdout and stderr from a process to the logger.
    """

    def __init__(self, process: Popen, logger: logging.Logger):
        self.process = process
        self.logger = logger
        self._evt = Event()

    def start(self):
        stdout = sys.stdout
        stderr = sys.stderr
        stdout_log_thread = Thread(target=self._stdout_monitor, args=[stdout])
        stdout_log_thread.start()
        stderr_log_thread = Thread(target=self._stderr_monitor, args=[stderr])
        stderr_log_thread.start()

    def stop(self):
        self._evt.set()

    def _stdout_monitor(self, stdout):
        sys.stdout = stdout
        # noinspection PyBroadException
        try:
            for line in self.process.stdout:
                if self._evt.is_set():
                    return

                self.logger.info(line.rstrip("\n"))
        except:  # noqa
            pass

    def _stderr_monitor(self, stderr):
        sys.stderr = stderr
        # noinspection PyBroadException
        try:
            for line in self.process.stderr:
                if self._evt.is_set():
                    return

                self.logger.info(line.rstrip("\n"))
        except:  # noqa
            pass


class ProcessDiedException(DazlError):
    pass



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import value_pb2 as _value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionFilter(_message.Message):
    __slots__ = ("filters_by_party",)
    class FiltersByPartyEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Filters
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Filters, _Mapping]] = ...) -> None: ...
    FILTERS_BY_PARTY_FIELD_NUMBER: _ClassVar[int]
    filters_by_party: _containers.MessageMap[str, Filters]
    def __init__(self, filters_by_party: _Optional[_Mapping[str, Filters]] = ...) -> None: ...

class Filters(_message.Message):
    __slots__ = ("inclusive",)
    INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    inclusive: InclusiveFilters
    def __init__(self, inclusive: _Optional[_Union[InclusiveFilters, _Mapping]] = ...) -> None: ...

class InclusiveFilters(_message.Message):
    __slots__ = ("template_ids", "interface_filters", "template_filters")
    TEMPLATE_IDS_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_FILTERS_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_FILTERS_FIELD_NUMBER: _ClassVar[int]
    template_ids: _containers.RepeatedCompositeFieldContainer[_value_pb2.Identifier]
    interface_filters: _containers.RepeatedCompositeFieldContainer[InterfaceFilter]
    template_filters: _containers.RepeatedCompositeFieldContainer[TemplateFilter]
    def __init__(self, template_ids: _Optional[_Iterable[_Union[_value_pb2.Identifier, _Mapping]]] = ..., interface_filters: _Optional[_Iterable[_Union[InterfaceFilter, _Mapping]]] = ..., template_filters: _Optional[_Iterable[_Union[TemplateFilter, _Mapping]]] = ...) -> None: ...

class InterfaceFilter(_message.Message):
    __slots__ = ("interface_id", "include_interface_view", "include_created_event_blob")
    INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_INTERFACE_VIEW_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_CREATED_EVENT_BLOB_FIELD_NUMBER: _ClassVar[int]
    interface_id: _value_pb2.Identifier
    include_interface_view: bool
    include_created_event_blob: bool
    def __init__(self, interface_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., include_interface_view: bool = ..., include_created_event_blob: bool = ...) -> None: ...

class TemplateFilter(_message.Message):
    __slots__ = ("template_id", "include_created_event_blob")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_CREATED_EVENT_BLOB_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    include_created_event_blob: bool
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., include_created_event_blob: bool = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HmacAlgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    HMAC_ALGORITHM_UNSPECIFIED: _ClassVar[HmacAlgorithm]
    HMAC_ALGORITHM_HMAC_SHA256: _ClassVar[HmacAlgorithm]
HMAC_ALGORITHM_UNSPECIFIED: HmacAlgorithm
HMAC_ALGORITHM_HMAC_SHA256: HmacAlgorithm

class Salt(_message.Message):
    __slots__ = ("hmac", "salt")
    HMAC_FIELD_NUMBER: _ClassVar[int]
    SALT_FIELD_NUMBER: _ClassVar[int]
    hmac: HmacAlgorithm
    salt: bytes
    def __init__(self, hmac: _Optional[_Union[HmacAlgorithm, str]] = ..., salt: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/topology.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v0/topology.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from . import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/digitalasset/canton/protocol/v0/topology.proto\x12#com.digitalasset.canton.protocol.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\"\xc0\x02\n\x10ParticipantState\x12\x44\n\x04side\x18\x01 \x01(\x0e\x32\x30.com.digitalasset.canton.protocol.v0.RequestSideR\x04side\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12 \n\x0bparticipant\x18\x03 \x01(\tR\x0bparticipant\x12Z\n\npermission\x18\x04 \x01(\x0e\x32:.com.digitalasset.canton.protocol.v0.ParticipantPermissionR\npermission\x12P\n\x0btrust_level\x18\x05 \x01(\x0e\x32/.com.digitalasset.canton.protocol.v0.TrustLevelR\ntrustLevel\"\xee\x01\n\x12PartyToParticipant\x12\x44\n\x04side\x18\x01 \x01(\x0e\x32\x30.com.digitalasset.canton.protocol.v0.RequestSideR\x04side\x12\x14\n\x05party\x18\x02 \x01(\tR\x05party\x12 \n\x0bparticipant\x18\x03 \x01(\tR\x0bparticipant\x12Z\n\npermission\x18\x04 \x01(\x0e\x32:.com.digitalasset.canton.protocol.v0.ParticipantPermissionR\npermission\"\x8f\x01\n\x13MediatorDomainState\x12\x44\n\x04side\x18\x01 \x01(\x0e\x32\x30.com.digitalasset.canton.protocol.v0.RequestSideR\x04side\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12\x1a\n\x08mediator\x18\x03 \x01(\tR\x08mediator\"\xb5\x01\n\x13NamespaceDelegation\x12\x1c\n\tnamespace\x18\x01 \x01(\tR\tnamespace\x12R\n\ntarget_key\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\ttargetKey\x12,\n\x12is_root_delegation\x18\x03 \x01(\x08R\x10isRootDelegation\"\x97\x01\n\x14IdentifierDelegation\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12R\n\ntarget_key\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\ttargetKey\"}\n\x11OwnerToKeyMapping\x12\x1b\n\tkey_owner\x18\x01 \x01(\tR\x08keyOwner\x12K\n\npublic_key\x18\x02 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.PublicKeyR\tpublicKey\"|\n\x18SignedLegalIdentityClaim\x12\x14\n\x05\x63laim\x18\x01 \x01(\x0cR\x05\x63laim\x12J\n\tsignature\x18\x02 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\tsignature\"l\n\x12LegalIdentityClaim\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12\x1d\n\tx509_cert\x18\x02 \x01(\x0cH\x00R\x08x509CertB\n\n\x08\x65vidence\"S\n\x0eVettedPackages\x12 \n\x0bparticipant\x18\x01 \x01(\tR\x0bparticipant\x12\x1f\n\x0bpackage_ids\x18\x02 \x03(\tR\npackageIds\"\xf4\x07\n\x13TopologyStateUpdate\x12S\n\toperation\x18\x01 \x01(\x0e\x32\x35.com.digitalasset.canton.protocol.v0.TopologyChangeOpR\toperation\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12m\n\x14namespace_delegation\x18\x03 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.NamespaceDelegationH\x00R\x13namespaceDelegation\x12p\n\x15identifier_delegation\x18\x04 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.IdentifierDelegationH\x00R\x14identifierDelegation\x12i\n\x14owner_to_key_mapping\x18\x05 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.OwnerToKeyMappingH\x00R\x11ownerToKeyMapping\x12k\n\x14party_to_participant\x18\x06 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v0.PartyToParticipantH\x00R\x12partyToParticipant\x12~\n\x1bsigned_legal_identity_claim\x18\x07 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v0.SignedLegalIdentityClaimH\x00R\x18signedLegalIdentityClaim\x12\x64\n\x11participant_state\x18\x08 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.ParticipantStateH\x00R\x10participantState\x12^\n\x0fvetted_packages\x18\t \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v0.VettedPackagesH\x00R\x0evettedPackages\x12n\n\x15mediator_domain_state\x18\n \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.MediatorDomainStateH\x00R\x13mediatorDomainStateB\t\n\x07mapping\"\x9b\x01\n\x16\x44omainParametersChange\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12i\n\x11\x64omain_parameters\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v0.DynamicDomainParametersR\x10\x64omainParameters\"\xa1\x01\n\x1b\x44omainGovernanceTransaction\x12w\n\x18\x64omain_parameters_change\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v0.DomainParametersChangeH\x00R\x16\x64omainParametersChangeB\t\n\x07mapping\"\xf4\x01\n\x13TopologyTransaction\x12]\n\x0cstate_update\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.TopologyStateUpdateH\x00R\x0bstateUpdate\x12o\n\x11\x64omain_governance\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v0.DomainGovernanceTransactionH\x00R\x10\x64omainGovernanceB\r\n\x0btransaction\"\xd0\x01\n\x19SignedTopologyTransaction\x12 \n\x0btransaction\x18\x01 \x01(\x0cR\x0btransaction\x12\x45\n\x03key\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\x03key\x12J\n\tsignature\x18\x03 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\tsignature\"\xaf\x01\n DomainTopologyTransactionMessage\x12J\n\tsignature\x18\x01 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\tsignature\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12\"\n\x0ctransactions\x18\x03 \x03(\x0cR\x0ctransactions\"\xe7\x01\n\"RegisterTopologyTransactionRequest\x12!\n\x0crequested_by\x18\x01 \x01(\tR\x0brequestedBy\x12 \n\x0bparticipant\x18\x02 \x01(\tR\x0bparticipant\x12\x1d\n\nrequest_id\x18\x03 \x01(\tR\trequestId\x12@\n\x1csigned_topology_transactions\x18\x04 \x03(\x0cR\x1asignedTopologyTransactions\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainId\"\xbf\x04\n#RegisterTopologyTransactionResponse\x12!\n\x0crequested_by\x18\x01 \x01(\tR\x0brequestedBy\x12 \n\x0bparticipant\x18\x02 \x01(\tR\x0bparticipant\x12\x1d\n\nrequest_id\x18\x03 \x01(\tR\trequestId\x12i\n\x07results\x18\x04 \x03(\x0b\x32O.com.digitalasset.canton.protocol.v0.RegisterTopologyTransactionResponse.ResultR\x07results\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainId\x1a\xab\x02\n\x06Result\x12\x1f\n\x0bunique_path\x18\x01 \x01(\tR\nuniquePath\x12k\n\x05state\x18\x02 \x01(\x0e\x32U.com.digitalasset.canton.protocol.v0.RegisterTopologyTransactionResponse.Result.StateR\x05state\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\"n\n\x05State\x12\x11\n\rMISSING_STATE\x10\x00\x12\r\n\tREQUESTED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0c\n\x08REJECTED\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x12\r\n\tDUPLICATE\x10\x05\x12\x0c\n\x08OBSOLETE\x10\x06*4\n\x10TopologyChangeOp\x12\x07\n\x03\x41\x64\x64\x10\x00\x12\n\n\x06Remove\x10\x01\x12\x0b\n\x07Replace\x10\x02*:\n\nTrustLevel\x12\x15\n\x11MissingTrustLevel\x10\x00\x12\x0c\n\x08Ordinary\x10\x01\x12\x07\n\x03Vip\x10\x02*z\n\x15ParticipantPermission\x12 \n\x1cMissingParticipantPermission\x10\x00\x12\x0e\n\nSubmission\x10\x01\x12\x10\n\x0c\x43onfirmation\x10\x02\x12\x0f\n\x0bObservation\x10\x03\x12\x0c\n\x08\x44isabled\x10\x04*A\n\x0bRequestSide\x12\x16\n\x12MissingRequestSide\x10\x00\x12\x08\n\x04\x42oth\x10\x01\x12\x08\n\x04\x46rom\x10\x02\x12\x06\n\x02To\x10\x03\x42TZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.topology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_TOPOLOGYCHANGEOP']._serialized_start=4474
  _globals['_TOPOLOGYCHANGEOP']._serialized_end=4526
  _globals['_TRUSTLEVEL']._serialized_start=4528
  _globals['_TRUSTLEVEL']._serialized_end=4586
  _globals['_PARTICIPANTPERMISSION']._serialized_start=4588
  _globals['_PARTICIPANTPERMISSION']._serialized_end=4710
  _globals['_REQUESTSIDE']._serialized_start=4712
  _globals['_REQUESTSIDE']._serialized_end=4777
  _globals['_PARTICIPANTSTATE']._serialized_start=194
  _globals['_PARTICIPANTSTATE']._serialized_end=514
  _globals['_PARTYTOPARTICIPANT']._serialized_start=517
  _globals['_PARTYTOPARTICIPANT']._serialized_end=755
  _globals['_MEDIATORDOMAINSTATE']._serialized_start=758
  _globals['_MEDIATORDOMAINSTATE']._serialized_end=901
  _globals['_NAMESPACEDELEGATION']._serialized_start=904
  _globals['_NAMESPACEDELEGATION']._serialized_end=1085
  _globals['_IDENTIFIERDELEGATION']._serialized_start=1088
  _globals['_IDENTIFIERDELEGATION']._serialized_end=1239
  _globals['_OWNERTOKEYMAPPING']._serialized_start=1241
  _globals['_OWNERTOKEYMAPPING']._serialized_end=1366
  _globals['_SIGNEDLEGALIDENTITYCLAIM']._serialized_start=1368
  _globals['_SIGNEDLEGALIDENTITYCLAIM']._serialized_end=1492
  _globals['_LEGALIDENTITYCLAIM']._serialized_start=1494
  _globals['_LEGALIDENTITYCLAIM']._serialized_end=1602
  _globals['_VETTEDPACKAGES']._serialized_start=1604
  _globals['_VETTEDPACKAGES']._serialized_end=1687
  _globals['_TOPOLOGYSTATEUPDATE']._serialized_start=1690
  _globals['_TOPOLOGYSTATEUPDATE']._serialized_end=2702
  _globals['_DOMAINPARAMETERSCHANGE']._serialized_start=2705
  _globals['_DOMAINPARAMETERSCHANGE']._serialized_end=2860
  _globals['_DOMAINGOVERNANCETRANSACTION']._serialized_start=2863
  _globals['_DOMAINGOVERNANCETRANSACTION']._serialized_end=3024
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=3027
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=3271
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_start=3274
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_end=3482
  _globals['_DOMAINTOPOLOGYTRANSACTIONMESSAGE']._serialized_start=3485
  _globals['_DOMAINTOPOLOGYTRANSACTIONMESSAGE']._serialized_end=3660
  _globals['_REGISTERTOPOLOGYTRANSACTIONREQUEST']._serialized_start=3663
  _globals['_REGISTERTOPOLOGYTRANSACTIONREQUEST']._serialized_end=3894
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE']._serialized_start=3897
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE']._serialized_end=4472
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_start=4173
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_end=4472
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT_STATE']._serialized_start=4362
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT_STATE']._serialized_end=4472
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v0/ledger_sync_event.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/protocol/v0/ledger_sync_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v0 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transaction__pb2
from ....protocol.v0 import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transfer__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/digitalasset/canton/participant/protocol/v0/ledger_sync_event.proto\x12/com.digitalasset.canton.participant.protocol.v0\x1a\x41\x63om/digitalasset/canton/protocol/v0/participant_transaction.proto\x1a>com/digitalasset/canton/protocol/v0/participant_transfer.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xec\x0b\n\x0fLedgerSyncEvent\x12|\n\x15\x63onfiguration_changed\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.participant.protocol.v0.ConfigurationChangedH\x00R\x14\x63onfigurationChanged\x12\x92\x01\n\x1d\x63onfiguration_change_rejected\x18\x02 \x01(\x0b\x32L.com.digitalasset.canton.participant.protocol.v0.ConfigurationChangeRejectedH\x00R\x1b\x63onfigurationChangeRejected\x12\x87\x01\n\x1aparty_added_to_participant\x18\x03 \x01(\x0b\x32H.com.digitalasset.canton.participant.protocol.v0.PartyAddedToParticipantH\x00R\x17partyAddedToParticipant\x12z\n\x15public_package_upload\x18\x04 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.protocol.v0.PublicPackageUploadH\x00R\x13publicPackageUpload\x12y\n\x14transaction_accepted\x18\x05 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.protocol.v0.TransactionAcceptedH\x00R\x13transactionAccepted\x12m\n\x10\x63ommand_rejected\x18\x06 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v0.CommandRejectedH\x00R\x0f\x63ommandRejected\x12\x86\x01\n\x19party_allocation_rejected\x18\x07 \x01(\x0b\x32H.com.digitalasset.canton.participant.protocol.v0.PartyAllocationRejectedH\x00R\x17partyAllocationRejected\x12\x93\x01\n\x1epublic_package_upload_rejected\x18\x08 \x01(\x0b\x32L.com.digitalasset.canton.participant.protocol.v0.PublicPackageUploadRejectedH\x00R\x1bpublicPackageUploadRejected\x12j\n\x0ftransferred_out\x18\t \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.TransferredOutH\x00R\x0etransferredOut\x12g\n\x0etransferred_in\x18\n \x01(\x0b\x32>.com.digitalasset.canton.participant.protocol.v0.TransferredInH\x00R\rtransferredIn\x12j\n\x0f\x63ontracts_added\x18\x0b \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.ContractsAddedH\x00R\x0e\x63ontractsAdded\x12m\n\x10\x63ontracts_purged\x18\x0c \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v0.ContractsPurgedH\x00R\x0f\x63ontractsPurgedB\x07\n\x05value\"\x85\x02\n\x14\x43onfigurationChanged\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12\x64\n\rconfiguration\x18\x02 \x01(\x0b\x32>.com.digitalasset.canton.participant.protocol.v0.ConfigurationR\rconfiguration\x12%\n\x0eparticipant_id\x18\x03 \x01(\tR\rparticipantId\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\"\xe3\x01\n\rConfiguration\x12\x1e\n\ngeneration\x18\x01 \x01(\x03R\ngeneration\x12Y\n\ntime_model\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.participant.protocol.v0.TimeModelR\ttimeModel\x12W\n\x1amax_deduplication_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18maxDeduplicationDuration\"\xca\x01\n\tTimeModel\x12Q\n\x17\x61vg_transaction_latency\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15\x61vgTransactionLatency\x12\x34\n\x08min_skew\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07minSkew\x12\x34\n\x08max_skew\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07maxSkew\"\xb4\x02\n\x1b\x43onfigurationChangeRejected\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\x12%\n\x0eparticipant_id\x18\x03 \x01(\tR\rparticipantId\x12:\n\nrecordTime\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12u\n\x16proposed_configuration\x18\x05 \x01(\x0b\x32>.com.digitalasset.canton.participant.protocol.v0.ConfigurationR\x15proposedConfiguration\"\xdb\x01\n\x17PartyAddedToParticipant\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12%\n\x0eparticipant_id\x18\x03 \x01(\tR\rparticipantId\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"\xcd\x01\n\x17PartyAllocationRejected\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12;\n\x0brecord_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12)\n\x10rejection_reason\x18\x04 \x01(\tR\x0frejectionReason\"\xe0\x01\n\x13PublicPackageUpload\x12\x1a\n\x08\x61rchives\x18\x01 \x03(\x0cR\x08\x61rchives\x12K\n\x12source_description\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11sourceDescription\x12;\n\x0brecord_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12#\n\rsubmission_id\x18\x04 \x01(\tR\x0csubmissionId\"\xaa\x01\n\x1bPublicPackageUploadRejected\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12;\n\x0brecord_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12)\n\x10rejection_reason\x18\x03 \x01(\tR\x0frejectionReason\"\xc2\x06\n\x13TransactionAccepted\x12h\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12k\n\x10transaction_meta\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v0.TransactionMetaR\x0ftransactionMeta\x12 \n\x0btransaction\x18\x03 \x01(\x0cR\x0btransaction\x12%\n\x0etransaction_id\x18\x04 \x01(\tR\rtransactionId\x12;\n\x0brecord_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12p\n\x12\x64ivulged_contracts\x18\x06 \x03(\x0b\x32\x41.com.digitalasset.canton.participant.protocol.v0.DivulgedContractR\x11\x64ivulgedContracts\x12\x62\n\rblinding_info\x18\x07 \x01(\x0b\x32=.com.digitalasset.canton.participant.protocol.v0.BlindingInfoR\x0c\x62lindingInfo\x12\x87\x01\n\x11\x63ontract_metadata\x18\x08 \x03(\x0b\x32Z.com.digitalasset.canton.participant.protocol.v0.TransactionAccepted.ContractMetadataEntryR\x10\x63ontractMetadata\x12)\n\x10hosted_witnesses\x18\t \x03(\tR\x0fhostedWitnesses\x1a\x43\n\x15\x43ontractMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\x84\x02\n\x0e\x43ompletionInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12%\n\x0e\x61pplication_id\x18\x02 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12p\n\x16optDeduplicationPeriod\x18\x04 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.DeduplicationPeriodR\x16optDeduplicationPeriod\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"\xd2\x04\n\x0fTransactionMeta\x12;\n\x0bledger_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nledgerTime\x12=\n\x0bworkflow_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nworkflowId\x12\x43\n\x0fsubmission_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0esubmissionTime\x12\'\n\x0fsubmission_seed\x18\x04 \x01(\x0cR\x0esubmissionSeed\x12#\n\rused_packages\x18\x05 \x03(\tR\x0cusedPackages\x12X\n\nnode_seeds\x18\x06 \x03(\x0b\x32\x39.com.digitalasset.canton.participant.protocol.v0.NodeSeedR\tnodeSeeds\x12m\n\x0c\x62y_key_nodes\x18\x07 \x01(\x0b\x32K.com.digitalasset.canton.participant.protocol.v0.TransactionMeta.ByKeyNodesR\nbyKeyNodes\x12\x39\n\tdomain_id\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x64omainId\x1a,\n\nByKeyNodes\x12\x1e\n\x0b\x62y_key_node\x18\x01 \x03(\x05R\tbyKeyNode\"F\n\x08NodeSeed\x12\x1d\n\nnode_index\x18\x01 \x01(\x05R\tnodeIndex\x12\x1b\n\tnode_seed\x18\x02 \x01(\x0cR\x08nodeSeed\"X\n\x10\x44ivulgedContract\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12#\n\rcontract_inst\x18\x02 \x01(\x0cR\x0c\x63ontractInst\"\xde\x03\n\x0c\x42lindingInfo\x12m\n\ndisclosure\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.participant.protocol.v0.BlindingInfo.DisclosureEntryR\ndisclosure\x12m\n\ndivulgence\x18\x02 \x03(\x0b\x32M.com.digitalasset.canton.participant.protocol.v0.BlindingInfo.DivulgenceEntryR\ndivulgence\x1aw\n\x0f\x44isclosureEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12N\n\x05value\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.participant.protocol.v0.PartiesR\x05value:\x02\x38\x01\x1aw\n\x0f\x44ivulgenceEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12N\n\x05value\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.participant.protocol.v0.PartiesR\x05value:\x02\x38\x01\"#\n\x07Parties\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\"\x95\x04\n\x0f\x43ommandRejected\x12h\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12;\n\x0brecord_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12\x87\x01\n\x10rejection_reason\x18\x03 \x01(\x0b\x32\\.com.digitalasset.canton.participant.protocol.v0.CommandRejected.GrpcRejectionReasonTemplateR\x0frejectionReason\x12_\n\x0c\x63ommand_kind\x18\x04 \x01(\x0e\x32<.com.digitalasset.canton.participant.protocol.v0.CommandKindR\x0b\x63ommandKind\x12\x39\n\tdomain_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x64omainId\x1a\x35\n\x1bGrpcRejectionReasonTemplate\x12\x16\n\x06status\x18\x01 \x01(\x0cR\x06status\"\xc4\x05\n\x0eTransferredOut\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12h\n\x0f\x63ompletion_info\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12\x1c\n\tsubmitter\x18\x03 \x01(\tR\tsubmitter\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12\x1f\n\x0b\x63ontract_id\x18\x05 \x01(\tR\ncontractId\x12\x33\n\x15\x63ontract_stakeholders\x18\x06 \x03(\tR\x14\x63ontractStakeholders\x12#\n\rsource_domain\x18\x07 \x01(\tR\x0csourceDomain\x12#\n\rtarget_domain\x18\x08 \x01(\tR\x0ctargetDomain\x12R\n\x17transfer_in_exclusivity\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15transferInExclusivity\x12\x1f\n\x0bworkflow_id\x18\n \x01(\tR\nworkflowId\x12\x1f\n\x0btemplate_id\x18\x0b \x01(\tR\ntemplateId\x12>\n\x1bis_transferring_participant\x18\x0c \x01(\x08R\x19isTransferringParticipant\x12/\n\x13hosted_stakeholders\x18\r \x03(\tR\x12hostedStakeholders\x12)\n\x10transfer_counter\x18\x0e \x01(\x03R\x0ftransferCounter\"\xbc\x06\n\rTransferredIn\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12h\n\x0f\x63ompletion_info\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12\x1c\n\tsubmitter\x18\x03 \x01(\tR\tsubmitter\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12H\n\x12ledger_create_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10ledgerCreateTime\x12\x1f\n\x0b\x63reate_node\x18\x06 \x01(\x0cR\ncreateNode\x12\x36\n\x17\x63reating_transaction_id\x18\x07 \x01(\tR\x15\x63reatingTransactionId\x12+\n\x11\x63ontract_metadata\x18\x08 \x01(\x0cR\x10\x63ontractMetadata\x12W\n\x0ftransfer_out_id\x18\t \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.TransferIdR\rtransferOutId\x12#\n\rtarget_domain\x18\n \x01(\tR\x0ctargetDomain\x12>\n\x1b\x63reate_transaction_accepted\x18\x0b \x01(\x08R\x19\x63reateTransactionAccepted\x12\x1f\n\x0bworkflow_id\x18\x0c \x01(\tR\nworkflowId\x12>\n\x1bis_transferring_participant\x18\r \x01(\x08R\x19isTransferringParticipant\x12/\n\x13hosted_stakeholders\x18\x0e \x03(\tR\x12hostedStakeholders\x12)\n\x10transfer_counter\x18\x0f \x01(\x03R\x0ftransferCounter\"\x82\x04\n\x0e\x43ontractsAdded\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1c\n\tcontracts\x18\x02 \x03(\x0cR\tcontracts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12;\n\x0bledger_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nledgerTime\x12;\n\x0brecord_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12)\n\x10hosted_witnesses\x18\x06 \x03(\tR\x0fhostedWitnesses\x12\x82\x01\n\x11\x63ontract_metadata\x18\x07 \x03(\x0b\x32U.com.digitalasset.canton.participant.protocol.v0.ContractsAdded.ContractMetadataEntryR\x10\x63ontractMetadata\x12\x1f\n\x0bworkflow_id\x18\x08 \x01(\tR\nworkflowId\x1a\x43\n\x15\x43ontractMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\xdb\x01\n\x0f\x43ontractsPurged\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1c\n\tcontracts\x18\x02 \x03(\x0cR\tcontracts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12)\n\x10hosted_witnesses\x18\x05 \x03(\tR\x0fhostedWitnesses*?\n\x0b\x43ommandKind\x12\x0f\n\x0bTransaction\x10\x00\x12\x0f\n\x0bTransferOut\x10\x01\x12\x0e\n\nTransferIn\x10\x02\x42`Z^github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v0.ledger_sync_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z^github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v0'
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._loaded_options = None
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._loaded_options = None
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_options = b'8\001'
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._loaded_options = None
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_options = b'8\001'
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._loaded_options = None
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_COMMANDKIND']._serialized_start=8905
  _globals['_COMMANDKIND']._serialized_end=8968
  _globals['_LEDGERSYNCEVENT']._serialized_start=353
  _globals['_LEDGERSYNCEVENT']._serialized_end=1869
  _globals['_CONFIGURATIONCHANGED']._serialized_start=1872
  _globals['_CONFIGURATIONCHANGED']._serialized_end=2133
  _globals['_CONFIGURATION']._serialized_start=2136
  _globals['_CONFIGURATION']._serialized_end=2363
  _globals['_TIMEMODEL']._serialized_start=2366
  _globals['_TIMEMODEL']._serialized_end=2568
  _globals['_CONFIGURATIONCHANGEREJECTED']._serialized_start=2571
  _globals['_CONFIGURATIONCHANGEREJECTED']._serialized_end=2879
  _globals['_PARTYADDEDTOPARTICIPANT']._serialized_start=2882
  _globals['_PARTYADDEDTOPARTICIPANT']._serialized_end=3101
  _globals['_PARTYALLOCATIONREJECTED']._serialized_start=3104
  _globals['_PARTYALLOCATIONREJECTED']._serialized_end=3309
  _globals['_PUBLICPACKAGEUPLOAD']._serialized_start=3312
  _globals['_PUBLICPACKAGEUPLOAD']._serialized_end=3536
  _globals['_PUBLICPACKAGEUPLOADREJECTED']._serialized_start=3539
  _globals['_PUBLICPACKAGEUPLOADREJECTED']._serialized_end=3709
  _globals['_TRANSACTIONACCEPTED']._serialized_start=3712
  _globals['_TRANSACTIONACCEPTED']._serialized_end=4546
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_start=4479
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_end=4546
  _globals['_COMPLETIONINFO']._serialized_start=4549
  _globals['_COMPLETIONINFO']._serialized_end=4809
  _globals['_TRANSACTIONMETA']._serialized_start=4812
  _globals['_TRANSACTIONMETA']._serialized_end=5406
  _globals['_TRANSACTIONMETA_BYKEYNODES']._serialized_start=5362
  _globals['_TRANSACTIONMETA_BYKEYNODES']._serialized_end=5406
  _globals['_NODESEED']._serialized_start=5408
  _globals['_NODESEED']._serialized_end=5478
  _globals['_DIVULGEDCONTRACT']._serialized_start=5480
  _globals['_DIVULGEDCONTRACT']._serialized_end=5568
  _globals['_BLINDINGINFO']._serialized_start=5571
  _globals['_BLINDINGINFO']._serialized_end=6049
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_start=5809
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_end=5928
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_start=5930
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_end=6049
  _globals['_PARTIES']._serialized_start=6051
  _globals['_PARTIES']._serialized_end=6086
  _globals['_COMMANDREJECTED']._serialized_start=6089
  _globals['_COMMANDREJECTED']._serialized_end=6622
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_start=6569
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_end=6622
  _globals['_TRANSFERREDOUT']._serialized_start=6625
  _globals['_TRANSFERREDOUT']._serialized_end=7333
  _globals['_TRANSFERREDIN']._serialized_start=7336
  _globals['_TRANSFERREDIN']._serialized_end=8164
  _globals['_CONTRACTSADDED']._serialized_start=8167
  _globals['_CONTRACTSADDED']._serialized_end=8681
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_start=4479
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_end=4546
  _globals['_CONTRACTSPURGED']._serialized_start=8684
  _globals['_CONTRACTSPURGED']._serialized_end=8903
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/inspection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/admin/participant/v30/inspection_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\x80\x02\n\x14LookupContractDomain\x1a*\n\x07Request\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x03(\tR\ncontractId\x1a\xbb\x01\n\x08Response\x12s\n\x07results\x18\x01 \x03(\x0b\x32Y.com.digitalasset.canton.admin.participant.v30.LookupContractDomain.Response.ResultsEntryR\x07results\x1a:\n\x0cResultsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"t\n\x17LookupTransactionDomain\x1a\x30\n\x07Request\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x1a\'\n\x08Response\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\"}\n\x12LookupOffsetByTime\x1a\x43\n\x07Request\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\"\n\x08Response\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\"Z\n\x13LookupOffsetByIndex\x1a\x1f\n\x07Request\x12\x14\n\x05index\x18\x01 \x01(\x03R\x05index\x1a\"\n\x08Response\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\"\xc9\x03\n\x1cLookupReceivedAcsCommitments\x1a\xb1\x02\n\x07Request\x12_\n\x0btime_ranges\x18\x01 \x03(\x0b\x32>.com.digitalasset.canton.admin.participant.v30.DomainTimeRangeR\ntimeRanges\x12\x38\n\x18\x63ounter_participant_uids\x18\x02 \x03(\tR\x16\x63ounterParticipantUids\x12q\n\x10\x63ommitment_state\x18\x03 \x03(\x0e\x32\x46.com.digitalasset.canton.admin.participant.v30.ReceivedCommitmentStateR\x0f\x63ommitmentState\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\x1au\n\x08Response\x12i\n\x08received\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.admin.participant.v30.ReceivedAcsCommitmentPerDomainR\x08received\"\x8d\x01\n\tTimeRange\x12\x41\n\x0e\x66rom_exclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rfromExclusive\x12=\n\x0cto_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btoInclusive\"\x96\x01\n\x0f\x44omainTimeRange\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12Y\n\x08interval\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.participant.v30.TimeRangeH\x00R\x08interval\x88\x01\x01\x42\x0b\n\t_interval\"\xa2\x01\n\x08Interval\x12L\n\x14start_tick_exclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12startTickExclusive\x12H\n\x12\x65nd_tick_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x65ndTickInclusive\"\x9c\x03\n\x15ReceivedAcsCommitment\x12S\n\x08interval\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.IntervalR\x08interval\x12\x43\n\x1eorigin_counter_participant_uid\x18\x02 \x01(\tR\x1boriginCounterParticipantUid\x12\x34\n\x13received_commitment\x18\x03 \x01(\x0cH\x00R\x12receivedCommitment\x88\x01\x01\x12*\n\x0eown_commitment\x18\x04 \x01(\x0cH\x01R\rownCommitment\x88\x01\x01\x12\\\n\x05state\x18\x05 \x01(\x0e\x32\x46.com.digitalasset.canton.admin.participant.v30.ReceivedCommitmentStateR\x05stateB\x16\n\x14_received_commitmentB\x11\n\x0f_own_commitment\"\x9f\x01\n\x1eReceivedAcsCommitmentPerDomain\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12`\n\x08received\x18\x02 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ReceivedAcsCommitmentR\x08received\"\x90\x03\n\x11SentAcsCommitment\x12S\n\x08interval\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.IntervalR\x08interval\x12?\n\x1c\x64\x65st_counter_participant_uid\x18\x02 \x01(\tR\x19\x64\x65stCounterParticipantUid\x12*\n\x0eown_commitment\x18\x03 \x01(\x0cH\x00R\rownCommitment\x88\x01\x01\x12\x34\n\x13received_commitment\x18\x04 \x01(\x0cH\x01R\x12receivedCommitment\x88\x01\x01\x12X\n\x05state\x18\x05 \x01(\x0e\x32\x42.com.digitalasset.canton.admin.participant.v30.SentCommitmentStateR\x05stateB\x11\n\x0f_own_commitmentB\x16\n\x14_received_commitment\"\x8f\x01\n\x1aSentAcsCommitmentPerDomain\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12T\n\x04sent\x18\x02 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.SentAcsCommitmentR\x04sent\"\xb5\x03\n\x18LookupSentAcsCommitments\x1a\xad\x02\n\x07Request\x12_\n\x0btime_ranges\x18\x01 \x03(\x0b\x32>.com.digitalasset.canton.admin.participant.v30.DomainTimeRangeR\ntimeRanges\x12\x38\n\x18\x63ounter_participant_uids\x18\x02 \x03(\tR\x16\x63ounterParticipantUids\x12m\n\x10\x63ommitment_state\x18\x03 \x03(\x0e\x32\x42.com.digitalasset.canton.admin.participant.v30.SentCommitmentStateR\x0f\x63ommitmentState\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\x1ai\n\x08Response\x12]\n\x04sent\x18\x01 \x03(\x0b\x32I.com.digitalasset.canton.admin.participant.v30.SentAcsCommitmentPerDomainR\x04sent\"\xa9\x02\n\"SlowCounterParticipantDomainConfig\x12\x1d\n\ndomain_ids\x18\x01 \x03(\tR\tdomainIds\x12\x44\n\x1e\x64istinguished_participant_uids\x18\x02 \x03(\tR\x1c\x64istinguishedParticipantUids\x12\x37\n\x17threshold_distinguished\x18\x03 \x01(\x04R\x16thresholdDistinguished\x12+\n\x11threshold_default\x18\x04 \x01(\x04R\x10thresholdDefault\x12\x38\n\x18participant_uids_metrics\x18\x05 \x03(\tR\x16participantUidsMetrics\"\xa9\x01\n#SetConfigForSlowCounterParticipants\x1av\n\x07Request\x12k\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.admin.participant.v30.SlowCounterParticipantDomainConfigR\x07\x63onfigs\x1a\n\n\x08Response\"\xc8\x01\n#GetConfigForSlowCounterParticipants\x1a(\n\x07Request\x12\x1d\n\ndomain_ids\x18\x02 \x03(\tR\tdomainIds\x1aw\n\x08Response\x12k\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.admin.participant.v30.SlowCounterParticipantDomainConfigR\x07\x63onfigs\"\xdd\x04\n(GetIntervalsBehindForCounterParticipants\x1a\xf1\x01\n\x16\x43ounterParticipantInfo\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12)\n\x10intervals_behind\x18\x03 \x01(\x04R\x0fintervalsBehind\x12W\n\x1a\x61s_of_sequencing_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x17\x61sOfSequencingTimestamp\x1a\x93\x01\n\x07Request\x12\x38\n\x18\x63ounter_participant_uids\x18\x01 \x03(\tR\x16\x63ounterParticipantUids\x12\x1d\n\ndomain_ids\x18\x02 \x03(\tR\tdomainIds\x12!\n\tthreshold\x18\x03 \x01(\x04H\x00R\tthreshold\x88\x01\x01\x42\x0c\n\n_threshold\x1a\xa6\x01\n\x08Response\x12\x99\x01\n\x10intervals_behind\x18\x01 \x03(\x0b\x32n.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipants.CounterParticipantInfoR\x0fintervalsBehind*\xe4\x01\n\x17ReceivedCommitmentState\x12)\n%RECEIVED_COMMITMENT_STATE_UNSPECIFIED\x10\x00\x12#\n\x1fRECEIVED_COMMITMENT_STATE_MATCH\x10\x01\x12&\n\"RECEIVED_COMMITMENT_STATE_MISMATCH\x10\x02\x12&\n\"RECEIVED_COMMITMENT_STATE_BUFFERED\x10\x03\x12)\n%RECEIVED_COMMITMENT_STATE_OUTSTANDING\x10\x04*\xa9\x01\n\x13SentCommitmentState\x12%\n!SENT_COMMITMENT_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bSENT_COMMITMENT_STATE_MATCH\x10\x01\x12\"\n\x1eSENT_COMMITMENT_STATE_MISMATCH\x10\x02\x12&\n\"SENT_COMMITMENT_STATE_NOT_COMPARED\x10\x03\x32\xe4\x0c\n\x11InspectionService\x12\xb1\x01\n\x14LookupContractDomain\x12K.com.digitalasset.canton.admin.participant.v30.LookupContractDomain.Request\x1aL.com.digitalasset.canton.admin.participant.v30.LookupContractDomain.Response\x12\xab\x01\n\x12LookupOffsetByTime\x12I.com.digitalasset.canton.admin.participant.v30.LookupOffsetByTime.Request\x1aJ.com.digitalasset.canton.admin.participant.v30.LookupOffsetByTime.Response\x12\xae\x01\n\x13LookupOffsetByIndex\x12J.com.digitalasset.canton.admin.participant.v30.LookupOffsetByIndex.Request\x1aK.com.digitalasset.canton.admin.participant.v30.LookupOffsetByIndex.Response\x12\xbd\x01\n\x18LookupSentAcsCommitments\x12O.com.digitalasset.canton.admin.participant.v30.LookupSentAcsCommitments.Request\x1aP.com.digitalasset.canton.admin.participant.v30.LookupSentAcsCommitments.Response\x12\xc9\x01\n\x1cLookupReceivedAcsCommitments\x12S.com.digitalasset.canton.admin.participant.v30.LookupReceivedAcsCommitments.Request\x1aT.com.digitalasset.canton.admin.participant.v30.LookupReceivedAcsCommitments.Response\x12\xde\x01\n#SetConfigForSlowCounterParticipants\x12Z.com.digitalasset.canton.admin.participant.v30.SetConfigForSlowCounterParticipants.Request\x1a[.com.digitalasset.canton.admin.participant.v30.SetConfigForSlowCounterParticipants.Response\x12\xde\x01\n#GetConfigForSlowCounterParticipants\x12Z.com.digitalasset.canton.admin.participant.v30.GetConfigForSlowCounterParticipants.Request\x1a[.com.digitalasset.canton.admin.participant.v30.GetConfigForSlowCounterParticipants.Response\x12\xed\x01\n(GetIntervalsBehindForCounterParticipants\x12_.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipants.Request\x1a`.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipants.ResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._loaded_options = None
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_options = b'8\001'
  _globals['_RECEIVEDCOMMITMENTSTATE']._serialized_start=4522
  _globals['_RECEIVEDCOMMITMENTSTATE']._serialized_end=4750
  _globals['_SENTCOMMITMENTSTATE']._serialized_start=4753
  _globals['_SENTCOMMITMENTSTATE']._serialized_end=4922
  _globals['_LOOKUPCONTRACTDOMAIN']._serialized_start=155
  _globals['_LOOKUPCONTRACTDOMAIN']._serialized_end=411
  _globals['_LOOKUPCONTRACTDOMAIN_REQUEST']._serialized_start=179
  _globals['_LOOKUPCONTRACTDOMAIN_REQUEST']._serialized_end=221
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE']._serialized_start=224
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE']._serialized_end=411
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_start=353
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_end=411
  _globals['_LOOKUPTRANSACTIONDOMAIN']._serialized_start=413
  _globals['_LOOKUPTRANSACTIONDOMAIN']._serialized_end=529
  _globals['_LOOKUPTRANSACTIONDOMAIN_REQUEST']._serialized_start=440
  _globals['_LOOKUPTRANSACTIONDOMAIN_REQUEST']._serialized_end=488
  _globals['_LOOKUPTRANSACTIONDOMAIN_RESPONSE']._serialized_start=490
  _globals['_LOOKUPTRANSACTIONDOMAIN_RESPONSE']._serialized_end=529
  _globals['_LOOKUPOFFSETBYTIME']._serialized_start=531
  _globals['_LOOKUPOFFSETBYTIME']._serialized_end=656
  _globals['_LOOKUPOFFSETBYTIME_REQUEST']._serialized_start=553
  _globals['_LOOKUPOFFSETBYTIME_REQUEST']._serialized_end=620
  _globals['_LOOKUPOFFSETBYTIME_RESPONSE']._serialized_start=622
  _globals['_LOOKUPOFFSETBYTIME_RESPONSE']._serialized_end=656
  _globals['_LOOKUPOFFSETBYINDEX']._serialized_start=658
  _globals['_LOOKUPOFFSETBYINDEX']._serialized_end=748
  _globals['_LOOKUPOFFSETBYINDEX_REQUEST']._serialized_start=681
  _globals['_LOOKUPOFFSETBYINDEX_REQUEST']._serialized_end=712
  _globals['_LOOKUPOFFSETBYINDEX_RESPONSE']._serialized_start=622
  _globals['_LOOKUPOFFSETBYINDEX_RESPONSE']._serialized_end=656
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS']._serialized_start=751
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS']._serialized_end=1208
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS_REQUEST']._serialized_start=784
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS_REQUEST']._serialized_end=1089
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS_RESPONSE']._serialized_start=1091
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTS_RESPONSE']._serialized_end=1208
  _globals['_TIMERANGE']._serialized_start=1211
  _globals['_TIMERANGE']._serialized_end=1352
  _globals['_DOMAINTIMERANGE']._serialized_start=1355
  _globals['_DOMAINTIMERANGE']._serialized_end=1505
  _globals['_INTERVAL']._serialized_start=1508
  _globals['_INTERVAL']._serialized_end=1670
  _globals['_RECEIVEDACSCOMMITMENT']._serialized_start=1673
  _globals['_RECEIVEDACSCOMMITMENT']._serialized_end=2085
  _globals['_RECEIVEDACSCOMMITMENTPERDOMAIN']._serialized_start=2088
  _globals['_RECEIVEDACSCOMMITMENTPERDOMAIN']._serialized_end=2247
  _globals['_SENTACSCOMMITMENT']._serialized_start=2250
  _globals['_SENTACSCOMMITMENT']._serialized_end=2650
  _globals['_SENTACSCOMMITMENTPERDOMAIN']._serialized_start=2653
  _globals['_SENTACSCOMMITMENTPERDOMAIN']._serialized_end=2796
  _globals['_LOOKUPSENTACSCOMMITMENTS']._serialized_start=2799
  _globals['_LOOKUPSENTACSCOMMITMENTS']._serialized_end=3236
  _globals['_LOOKUPSENTACSCOMMITMENTS_REQUEST']._serialized_start=2828
  _globals['_LOOKUPSENTACSCOMMITMENTS_REQUEST']._serialized_end=3129
  _globals['_LOOKUPSENTACSCOMMITMENTS_RESPONSE']._serialized_start=3131
  _globals['_LOOKUPSENTACSCOMMITMENTS_RESPONSE']._serialized_end=3236
  _globals['_SLOWCOUNTERPARTICIPANTDOMAINCONFIG']._serialized_start=3239
  _globals['_SLOWCOUNTERPARTICIPANTDOMAINCONFIG']._serialized_end=3536
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS']._serialized_start=3539
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS']._serialized_end=3708
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS_REQUEST']._serialized_start=3578
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS_REQUEST']._serialized_end=3696
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS_RESPONSE']._serialized_start=224
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTS_RESPONSE']._serialized_end=234
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS']._serialized_start=3711
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS']._serialized_end=3911
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS_REQUEST']._serialized_start=3750
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS_REQUEST']._serialized_end=3790
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS_RESPONSE']._serialized_start=3792
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTS_RESPONSE']._serialized_end=3911
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS']._serialized_start=3914
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS']._serialized_end=4519
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_COUNTERPARTICIPANTINFO']._serialized_start=3959
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_COUNTERPARTICIPANTINFO']._serialized_end=4200
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_REQUEST']._serialized_start=4203
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_REQUEST']._serialized_end=4350
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_RESPONSE']._serialized_start=4353
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTS_RESPONSE']._serialized_end=4519
  _globals['_INSPECTIONSERVICE']._serialized_start=4925
  _globals['_INSPECTIONSERVICE']._serialized_end=6561
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v0 import sequencing_pb2 as _sequencing_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetServiceAgreementRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetServiceAgreementResponse(_message.Message):
    __slots__ = ("agreement",)
    AGREEMENT_FIELD_NUMBER: _ClassVar[int]
    agreement: _sequencing_pb2.ServiceAgreement
    def __init__(self, agreement: _Optional[_Union[_sequencing_pb2.ServiceAgreement, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import object_meta_pb2 as _object_meta_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ("id", "primary_party", "is_deactivated", "metadata", "identity_provider_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_PARTY_FIELD_NUMBER: _ClassVar[int]
    IS_DEACTIVATED_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    primary_party: str
    is_deactivated: bool
    metadata: _object_meta_pb2.ObjectMeta
    identity_provider_id: str
    def __init__(self, id: _Optional[str] = ..., primary_party: _Optional[str] = ..., is_deactivated: bool = ..., metadata: _Optional[_Union[_object_meta_pb2.ObjectMeta, _Mapping]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class Right(_message.Message):
    __slots__ = ("participant_admin", "can_act_as", "can_read_as", "identity_provider_admin")
    class ParticipantAdmin(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class CanActAs(_message.Message):
        __slots__ = ("party",)
        PARTY_FIELD_NUMBER: _ClassVar[int]
        party: str
        def __init__(self, party: _Optional[str] = ...) -> None: ...
    class CanReadAs(_message.Message):
        __slots__ = ("party",)
        PARTY_FIELD_NUMBER: _ClassVar[int]
        party: str
        def __init__(self, party: _Optional[str] = ...) -> None: ...
    class IdentityProviderAdmin(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    PARTICIPANT_ADMIN_FIELD_NUMBER: _ClassVar[int]
    CAN_ACT_AS_FIELD_NUMBER: _ClassVar[int]
    CAN_READ_AS_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ADMIN_FIELD_NUMBER: _ClassVar[int]
    participant_admin: Right.ParticipantAdmin
    can_act_as: Right.CanActAs
    can_read_as: Right.CanReadAs
    identity_provider_admin: Right.IdentityProviderAdmin
    def __init__(self, participant_admin: _Optional[_Union[Right.ParticipantAdmin, _Mapping]] = ..., can_act_as: _Optional[_Union[Right.CanActAs, _Mapping]] = ..., can_read_as: _Optional[_Union[Right.CanReadAs, _Mapping]] = ..., identity_provider_admin: _Optional[_Union[Right.IdentityProviderAdmin, _Mapping]] = ...) -> None: ...

class CreateUserRequest(_message.Message):
    __slots__ = ("user", "rights")
    USER_FIELD_NUMBER: _ClassVar[int]
    RIGHTS_FIELD_NUMBER: _ClassVar[int]
    user: User
    rights: _containers.RepeatedCompositeFieldContainer[Right]
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ..., rights: _Optional[_Iterable[_Union[Right, _Mapping]]] = ...) -> None: ...

class CreateUserResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class GetUserRequest(_message.Message):
    __slots__ = ("user_id", "identity_provider_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    identity_provider_id: str
    def __init__(self, user_id: _Optional[str] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class GetUserResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class UpdateUserRequest(_message.Message):
    __slots__ = ("user", "update_mask")
    USER_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    user: User
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UpdateUserResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class DeleteUserRequest(_message.Message):
    __slots__ = ("user_id", "identity_provider_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    identity_provider_id: str
    def __init__(self, user_id: _Optional[str] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class DeleteUserResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListUsersRequest(_message.Message):
    __slots__ = ("page_token", "page_size", "identity_provider_id")
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    page_token: str
    page_size: int
    identity_provider_id: str
    def __init__(self, page_token: _Optional[str] = ..., page_size: _Optional[int] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class ListUsersResponse(_message.Message):
    __slots__ = ("users", "next_page_token")
    USERS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[User]
    next_page_token: str
    def __init__(self, users: _Optional[_Iterable[_Union[User, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class GrantUserRightsRequest(_message.Message):
    __slots__ = ("user_id", "rights", "identity_provider_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    RIGHTS_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    rights: _containers.RepeatedCompositeFieldContainer[Right]
    identity_provider_id: str
    def __init__(self, user_id: _Optional[str] = ..., rights: _Optional[_Iterable[_Union[Right, _Mapping]]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class GrantUserRightsResponse(_message.Message):
    __slots__ = ("newly_granted_rights",)
    NEWLY_GRANTED_RIGHTS_FIELD_NUMBER: _ClassVar[int]
    newly_granted_rights: _containers.RepeatedCompositeFieldContainer[Right]
    def __init__(self, newly_granted_rights: _Optional[_Iterable[_Union[Right, _Mapping]]] = ...) -> None: ...

class RevokeUserRightsRequest(_message.Message):
    __slots__ = ("user_id", "rights", "identity_provider_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    RIGHTS_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    rights: _containers.RepeatedCompositeFieldContainer[Right]
    identity_provider_id: str
    def __init__(self, user_id: _Optional[str] = ..., rights: _Optional[_Iterable[_Union[Right, _Mapping]]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class RevokeUserRightsResponse(_message.Message):
    __slots__ = ("newly_revoked_rights",)
    NEWLY_REVOKED_RIGHTS_FIELD_NUMBER: _ClassVar[int]
    newly_revoked_rights: _containers.RepeatedCompositeFieldContainer[Right]
    def __init__(self, newly_revoked_rights: _Optional[_Iterable[_Union[Right, _Mapping]]] = ...) -> None: ...

class ListUserRightsRequest(_message.Message):
    __slots__ = ("user_id", "identity_provider_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    identity_provider_id: str
    def __init__(self, user_id: _Optional[str] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class ListUserRightsResponse(_message.Message):
    __slots__ = ("rights",)
    RIGHTS_FIELD_NUMBER: _ClassVar[int]
    rights: _containers.RepeatedCompositeFieldContainer[Right]
    def __init__(self, rights: _Optional[_Iterable[_Union[Right, _Mapping]]] = ...) -> None: ...

class UpdateUserIdentityProviderRequest(_message.Message):
    __slots__ = ("user_id", "source_identity_provider_id", "target_identity_provider_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    source_identity_provider_id: str
    target_identity_provider_id: str
    def __init__(self, user_id: _Optional[str] = ..., source_identity_provider_id: _Optional[str] = ..., target_identity_provider_id: _Optional[str] = ...) -> None: ...

class UpdateUserIdentityProviderResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/event_query_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/event_query_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import event_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0com/daml/ledger/api/v2/event_query_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/event.proto\"n\n\x1cGetEventsByContractIdRequest\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12-\n\x12requesting_parties\x18\x02 \x03(\tR\x11requestingParties\"\x98\x01\n\x1dGetEventsByContractIdResponse\x12\x39\n\x07\x63reated\x18\x01 \x01(\x0b\x32\x1f.com.daml.ledger.api.v2.CreatedR\x07\x63reated\x12<\n\x08\x61rchived\x18\x02 \x01(\x0b\x32 .com.daml.ledger.api.v2.ArchivedR\x08\x61rchived\"q\n\x07\x43reated\x12I\n\rcreated_event\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v2.CreatedEventR\x0c\x63reatedEvent\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\"u\n\x08\x41rchived\x12L\n\x0e\x61rchived_event\x18\x01 \x01(\x0b\x32%.com.daml.ledger.api.v2.ArchivedEventR\rarchivedEvent\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId2\x9a\x01\n\x11\x45ventQueryService\x12\x84\x01\n\x15GetEventsByContractId\x12\x34.com.daml.ledger.api.v2.GetEventsByContractIdRequest\x1a\x35.com.daml.ledger.api.v2.GetEventsByContractIdResponseB\x95\x01\n\x16\x63om.daml.ledger.api.v2B\x1b\x45ventQueryServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.event_query_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\033EventQueryServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_GETEVENTSBYCONTRACTIDREQUEST']._serialized_start=112
  _globals['_GETEVENTSBYCONTRACTIDREQUEST']._serialized_end=222
  _globals['_GETEVENTSBYCONTRACTIDRESPONSE']._serialized_start=225
  _globals['_GETEVENTSBYCONTRACTIDRESPONSE']._serialized_end=377
  _globals['_CREATED']._serialized_start=379
  _globals['_CREATED']._serialized_end=492
  _globals['_ARCHIVED']._serialized_start=494
  _globals['_ARCHIVED']._serialized_end=611
  _globals['_EVENTQUERYSERVICE']._serialized_start=614
  _globals['_EVENTQUERYSERVICE']._serialized_end=768
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LedgerOffset(_message.Message):
    __slots__ = ("absolute", "boundary")
    class LedgerBoundary(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        LEDGER_BEGIN: _ClassVar[LedgerOffset.LedgerBoundary]
        LEDGER_END: _ClassVar[LedgerOffset.LedgerBoundary]
    LEDGER_BEGIN: LedgerOffset.LedgerBoundary
    LEDGER_END: LedgerOffset.LedgerBoundary
    ABSOLUTE_FIELD_NUMBER: _ClassVar[int]
    BOUNDARY_FIELD_NUMBER: _ClassVar[int]
    absolute: str
    boundary: LedgerOffset.LedgerBoundary
    def __init__(self, absolute: _Optional[str] = ..., boundary: _Optional[_Union[LedgerOffset.LedgerBoundary, str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from os import PathLike, fspath
import sys
from typing import TYPE_CHECKING, Optional, TypedDict

from .log import LoggerArgs

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

if TYPE_CHECKING:
    # We refer to the Config class in a docstring and
    # without this import, Sphinx can't resolve the reference
    # noinspection PyUnresolvedReferences
    from . import Config


__all__ = ["SSLConfig", "SSLConfigArgs", "_SSLConfigArgs"]


class SSLConfigArgs(TypedDict, total=False):
    ca: Optional[bytes]
    ca_file: Optional[PathLike]
    cert: Optional[bytes]
    cert_file: Optional[PathLike]
    cert_key: Optional[bytes]
    cert_key_file: Optional[PathLike]


class _SSLConfigArgs(SSLConfigArgs, LoggerArgs, total=False):
    pass


class SSLConfig:
    """
    Configuration parameters that affect SSL connections.

    See :meth:`Config.create` for a more detailed description of these parameters.
    """

    def __init__(self, **kwargs: Unpack[_SSLConfigArgs]):
        self._ca = kwargs.get("ca", None)
        self._cert = kwargs.get("cert", None)
        self._cert_key = kwargs.get("cert_key", None)

        if ca_file := kwargs.get("ca_file", None):
            if self._ca:
                raise ValueError("ca and ca_file cannot both be specified at the same time")
            with open(fspath(ca_file), "rb") as f:
                self._ca = f.read()

        if cert_file := kwargs.get("cert_file", None):
            if self._cert:
                raise ValueError("cert and cert_file cannot both be specified at the same time")
            with open(fspath(cert_file), "rb") as f:
                self._cert = f.read()

        if cert_key_file := kwargs.get("cert_key_file", None):
            if self._cert_key:
                raise ValueError(
                    "cert_key and cert_key_file cannot both be specified at the same time"
                )
            with open(fspath(cert_key_file), "rb") as f:
                self._cert_key = f.read()

    def __bool__(self):
        """
        True if SSL settings are supplied; otherwise False if no SSL settings of any kind were
        supplied.
        """
        return bool(self._ca or self._cert or self._cert_key)

    @property
    def ca(self) -> Optional[bytes]:
        """
        Server certificate authority file.
        """
        return self._ca

    @property
    def cert(self) -> Optional[bytes]:
        """
        Client certificate file.
        """
        return self._cert

    @property
    def cert_key(self) -> Optional[bytes]:
        """
        Client certificate and key file.
        """
        return self._cert_key



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/enterprise_sequencer_connection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/admin/v0/enterprise_sequencer_connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...api.v0 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connection__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUcom/digitalasset/canton/domain/admin/v0/enterprise_sequencer_connection_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a@com/digitalasset/canton/domain/api/v0/sequencer_connection.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x16\n\x14GetConnectionRequest\"\xc2\x01\n\x15GetConnectionResponse\x12o\n\x15sequencer_connections\x18\x01 \x03(\x0b\x32:.com.digitalasset.canton.domain.api.v0.SequencerConnectionR\x14sequencerConnections\x12\x38\n\x17sequencerTrustThreshold\x18\x02 \x01(\rR\x17sequencerTrustThreshold\"\xc1\x01\n\x14SetConnectionRequest\x12o\n\x15sequencer_connections\x18\x01 \x03(\x0b\x32:.com.digitalasset.canton.domain.api.v0.SequencerConnectionR\x14sequencerConnections\x12\x38\n\x17sequencerTrustThreshold\x18\x02 \x01(\rR\x17sequencerTrustThreshold2\x9f\x02\n$EnterpriseSequencerConnectionService\x12\x8e\x01\n\rGetConnection\x12=.com.digitalasset.canton.domain.admin.v0.GetConnectionRequest\x1a>.com.digitalasset.canton.domain.admin.v0.GetConnectionResponse\x12\x66\n\rSetConnection\x12=.com.digitalasset.canton.domain.admin.v0.SetConnectionRequest\x1a\x16.google.protobuf.EmptyBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.enterprise_sequencer_connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_GETCONNECTIONREQUEST']._serialized_start=225
  _globals['_GETCONNECTIONREQUEST']._serialized_end=247
  _globals['_GETCONNECTIONRESPONSE']._serialized_start=250
  _globals['_GETCONNECTIONRESPONSE']._serialized_end=444
  _globals['_SETCONNECTIONREQUEST']._serialized_start=447
  _globals['_SETCONNECTIONREQUEST']._serialized_end=640
  _globals['_ENTERPRISESEQUENCERCONNECTIONSERVICE']._serialized_start=643
  _globals['_ENTERPRISESEQUENCERCONNECTIONSERVICE']._serialized_end=930
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopologyTransactions(_message.Message):
    __slots__ = ("items",)
    class Item(_message.Message):
        __slots__ = ("sequenced", "valid_from", "valid_until", "transaction")
        SEQUENCED_FIELD_NUMBER: _ClassVar[int]
        VALID_FROM_FIELD_NUMBER: _ClassVar[int]
        VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
        TRANSACTION_FIELD_NUMBER: _ClassVar[int]
        sequenced: _timestamp_pb2.Timestamp
        valid_from: _timestamp_pb2.Timestamp
        valid_until: _timestamp_pb2.Timestamp
        transaction: bytes
        def __init__(self, sequenced: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., valid_from: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., valid_until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., transaction: _Optional[bytes] = ...) -> None: ...
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[TopologyTransactions.Item]
    def __init__(self, items: _Optional[_Iterable[_Union[TopologyTransactions.Item, _Mapping]]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListPackageContentsRequest(_message.Message):
    __slots__ = ("package_id",)
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    def __init__(self, package_id: _Optional[str] = ...) -> None: ...

class ListPackageContentsResponse(_message.Message):
    __slots__ = ("modules",)
    MODULES_FIELD_NUMBER: _ClassVar[int]
    modules: _containers.RepeatedCompositeFieldContainer[ModuleDescription]
    def __init__(self, modules: _Optional[_Iterable[_Union[ModuleDescription, _Mapping]]] = ...) -> None: ...

class ListDarContentsRequest(_message.Message):
    __slots__ = ("dar_id",)
    DAR_ID_FIELD_NUMBER: _ClassVar[int]
    dar_id: str
    def __init__(self, dar_id: _Optional[str] = ...) -> None: ...

class ListDarContentsResponse(_message.Message):
    __slots__ = ("description", "main", "packages", "dependencies")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    MAIN_FIELD_NUMBER: _ClassVar[int]
    PACKAGES_FIELD_NUMBER: _ClassVar[int]
    DEPENDENCIES_FIELD_NUMBER: _ClassVar[int]
    description: str
    main: str
    packages: _containers.RepeatedScalarFieldContainer[str]
    dependencies: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, description: _Optional[str] = ..., main: _Optional[str] = ..., packages: _Optional[_Iterable[str]] = ..., dependencies: _Optional[_Iterable[str]] = ...) -> None: ...

class RemovePackageRequest(_message.Message):
    __slots__ = ("package_id", "force")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    force: bool
    def __init__(self, package_id: _Optional[str] = ..., force: bool = ...) -> None: ...

class RemovePackageResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: _empty_pb2.Empty
    def __init__(self, success: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class VetDarRequest(_message.Message):
    __slots__ = ("dar_hash", "synchronize")
    DAR_HASH_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZE_FIELD_NUMBER: _ClassVar[int]
    dar_hash: str
    synchronize: bool
    def __init__(self, dar_hash: _Optional[str] = ..., synchronize: bool = ...) -> None: ...

class VetDarResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UnvetDarRequest(_message.Message):
    __slots__ = ("dar_hash",)
    DAR_HASH_FIELD_NUMBER: _ClassVar[int]
    dar_hash: str
    def __init__(self, dar_hash: _Optional[str] = ...) -> None: ...

class UnvetDarResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RemoveDarRequest(_message.Message):
    __slots__ = ("dar_hash",)
    DAR_HASH_FIELD_NUMBER: _ClassVar[int]
    dar_hash: str
    def __init__(self, dar_hash: _Optional[str] = ...) -> None: ...

class RemoveDarResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: _empty_pb2.Empty
    def __init__(self, success: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class ModuleDescription(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListPackagesRequest(_message.Message):
    __slots__ = ("limit",)
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    limit: int
    def __init__(self, limit: _Optional[int] = ...) -> None: ...

class ListPackagesResponse(_message.Message):
    __slots__ = ("package_descriptions",)
    PACKAGE_DESCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    package_descriptions: _containers.RepeatedCompositeFieldContainer[PackageDescription]
    def __init__(self, package_descriptions: _Optional[_Iterable[_Union[PackageDescription, _Mapping]]] = ...) -> None: ...

class ListDarsRequest(_message.Message):
    __slots__ = ("limit",)
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    limit: int
    def __init__(self, limit: _Optional[int] = ...) -> None: ...

class ListDarsResponse(_message.Message):
    __slots__ = ("dars",)
    DARS_FIELD_NUMBER: _ClassVar[int]
    dars: _containers.RepeatedCompositeFieldContainer[DarDescription]
    def __init__(self, dars: _Optional[_Iterable[_Union[DarDescription, _Mapping]]] = ...) -> None: ...

class DarDescription(_message.Message):
    __slots__ = ("hash", "name")
    HASH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    hash: str
    name: str
    def __init__(self, hash: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class UploadDarRequest(_message.Message):
    __slots__ = ("data", "filename", "vet_all_packages", "synchronize_vetting")
    DATA_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    VET_ALL_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZE_VETTING_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    filename: str
    vet_all_packages: bool
    synchronize_vetting: bool
    def __init__(self, data: _Optional[bytes] = ..., filename: _Optional[str] = ..., vet_all_packages: bool = ..., synchronize_vetting: bool = ...) -> None: ...

class UploadDarResponse(_message.Message):
    __slots__ = ("success", "failure")
    class Success(_message.Message):
        __slots__ = ("hash",)
        HASH_FIELD_NUMBER: _ClassVar[int]
        hash: str
        def __init__(self, hash: _Optional[str] = ...) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("reason",)
        REASON_FIELD_NUMBER: _ClassVar[int]
        reason: str
        def __init__(self, reason: _Optional[str] = ...) -> None: ...
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    success: UploadDarResponse.Success
    failure: UploadDarResponse.Failure
    def __init__(self, success: _Optional[_Union[UploadDarResponse.Success, _Mapping]] = ..., failure: _Optional[_Union[UploadDarResponse.Failure, _Mapping]] = ...) -> None: ...

class ValidateDarRequest(_message.Message):
    __slots__ = ("data", "filename")
    DATA_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    filename: str
    def __init__(self, data: _Optional[bytes] = ..., filename: _Optional[str] = ...) -> None: ...

class ValidateDarResponse(_message.Message):
    __slots__ = ("hash",)
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: str
    def __init__(self, hash: _Optional[str] = ...) -> None: ...

class GetDarRequest(_message.Message):
    __slots__ = ("hash",)
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: str
    def __init__(self, hash: _Optional[str] = ...) -> None: ...

class GetDarResponse(_message.Message):
    __slots__ = ("data", "name")
    DATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    name: str
    def __init__(self, data: _Optional[bytes] = ..., name: _Optional[str] = ...) -> None: ...

class PackageDescription(_message.Message):
    __slots__ = ("package_id", "source_description")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    source_description: str
    def __init__(self, package_id: _Optional[str] = ..., source_description: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TraceContext(_message.Message):
    __slots__ = ("traceparent", "tracestate")
    TRACEPARENT_FIELD_NUMBER: _ClassVar[int]
    TRACESTATE_FIELD_NUMBER: _ClassVar[int]
    traceparent: str
    tracestate: str
    def __init__(self, traceparent: _Optional[str] = ..., tracestate: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import service_agreement_pb2 as _service_agreement_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/mediator/admin/v30/sequencer_connection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/mediator/admin/v30/sequencer_connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....admin.domain.v30 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_domain_dot_v30_dot_sequencer__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/mediator/admin/v30/sequencer_connection_service.proto\x12*com.digitalasset.canton.mediator.admin.v30\x1a\x43\x63om/digitalasset/canton/admin/domain/v30/sequencer_connection.proto\"\x16\n\x14GetConnectionRequest\"\x8c\x01\n\x15GetConnectionResponse\x12s\n\x15sequencer_connections\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.admin.domain.v30.SequencerConnectionsR\x14sequencerConnections\"\x9d\x02\n\x14SetConnectionRequest\x12s\n\x15sequencer_connections\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.admin.domain.v30.SequencerConnectionsR\x14sequencerConnections\x12\x8f\x01\n\x1fsequencer_connection_validation\x18\x02 \x01(\x0e\x32G.com.digitalasset.canton.admin.domain.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"\x17\n\x15SetConnectionResponse2\xca\x02\n\x1aSequencerConnectionService\x12\x94\x01\n\rGetConnection\x12@.com.digitalasset.canton.mediator.admin.v30.GetConnectionRequest\x1a\x41.com.digitalasset.canton.mediator.admin.v30.GetConnectionResponse\x12\x94\x01\n\rSetConnection\x12@.com.digitalasset.canton.mediator.admin.v30.SetConnectionRequest\x1a\x41.com.digitalasset.canton.mediator.admin.v30.SetConnectionResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/mediator/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.mediator.admin.v30.sequencer_connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/mediator/admin/v30'
  _globals['_GETCONNECTIONREQUEST']._serialized_start=194
  _globals['_GETCONNECTIONREQUEST']._serialized_end=216
  _globals['_GETCONNECTIONRESPONSE']._serialized_start=219
  _globals['_GETCONNECTIONRESPONSE']._serialized_end=359
  _globals['_SETCONNECTIONREQUEST']._serialized_start=362
  _globals['_SETCONNECTIONREQUEST']._serialized_end=647
  _globals['_SETCONNECTIONRESPONSE']._serialized_start=649
  _globals['_SETCONNECTIONRESPONSE']._serialized_end=672
  _globals['_SEQUENCERCONNECTIONSERVICE']._serialized_start=675
  _globals['_SEQUENCERCONNECTIONSERVICE']._serialized_end=1005
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v30 import crypto_pb2 as _crypto_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ViewType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VIEW_TYPE_UNSPECIFIED: _ClassVar[ViewType]
    VIEW_TYPE_TRANSACTION: _ClassVar[ViewType]
    VIEW_TYPE_TRANSFER_OUT: _ClassVar[ViewType]
    VIEW_TYPE_TRANSFER_IN: _ClassVar[ViewType]
VIEW_TYPE_UNSPECIFIED: ViewType
VIEW_TYPE_TRANSACTION: ViewType
VIEW_TYPE_TRANSFER_OUT: ViewType
VIEW_TYPE_TRANSFER_IN: ViewType

class DriverContractMetadata(_message.Message):
    __slots__ = ("contract_salt",)
    CONTRACT_SALT_FIELD_NUMBER: _ClassVar[int]
    contract_salt: _crypto_pb2.Salt
    def __init__(self, contract_salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from contextlib import ExitStack
import io
import os
from pathlib import Path
from shutil import rmtree
from tempfile import TemporaryDirectory
from typing import Collection, Mapping, Optional, Protocol
from zipfile import ZipFile

from . import rename, rewrite
from .. import protoc

__all__ = ["build"]


class Renamer(Protocol):
    def __call__(self, zip_file_list: Collection[str], /) -> Mapping[str, str]: ...


class Rewriter(Protocol):
    def __call__(self, target_name: str, contents: str, /) -> str: ...


def build(
    *,
    canton_2_zip: Path,
    daml_2_protos_zip: Path,
    daml_3_protos_zip: Path,
    to: Path,
    cache_dir: Optional[Path] = None,
) -> None:
    with ExitStack() as stack:
        canton_2 = stack.enter_context(ZipFile(canton_2_zip))
        daml_2_proto = stack.enter_context(ZipFile(daml_2_protos_zip))
        daml_3_proto = stack.enter_context(ZipFile(daml_3_protos_zip))

        if cache_dir is not None:
            rmtree(cache_dir)
        else:
            cache_dir = Path(stack.enter_context(TemporaryDirectory()))

        _build_zip_part(
            archive=canton_2,
            out_dir=cache_dir,
            renamer=rename.canton_proto_files,
            rewriter=rewrite.canton_proto_rewrite,
        )

        if canton_3_dir := os.getenv("CN_ENTERPRISE_PATH"):
            _build_dir_part(
                input_dir=Path(canton_3_dir),
                out_dir=cache_dir,
                renamer=rename.canton_proto_files,
                rewriter=rewrite.canton_proto_rewrite,
            )

        _build_zip_part(
            archive=daml_2_proto,
            out_dir=cache_dir,
            renamer=lambda names: rename.daml_proto_files(names, "v1"),
            rewriter=rewrite.daml_proto_rewrite,
        )

        _build_zip_part(
            archive=daml_3_proto,
            out_dir=cache_dir,
            renamer=lambda names: rename.daml_proto_files(names, "v2"),
            rewriter=rewrite.daml_proto_rewrite,
        )

        protoc.generate_descriptors(cache_dir, to)


def _build_zip_part(archive: ZipFile, out_dir: Path, renamer: Renamer, rewriter: Rewriter) -> None:
    proto_files = renamer(archive.namelist())

    for target_name, zip_name in proto_files.items():
        with archive.open(zip_name) as r:
            with io.TextIOWrapper(r) as buf_in:
                contents = rewriter(target_name, buf_in.read())

        out_file = out_dir / target_name
        out_file.parent.mkdir(parents=True, exist_ok=True)
        out_file.write_text(contents)


def _build_dir_part(input_dir: Path, out_dir: Path, renamer: Renamer, rewriter: Rewriter) -> None:
    proto_files = renamer(
        [
            str(input_name.relative_to(input_dir.parent))
            for input_name in input_dir.glob("**/*.proto")
        ]
    )

    for target_name, original_name in proto_files.items():
        input_name = input_dir.parent / original_name
        with input_name.open() as buf_in:
            contents = rewriter(target_name, buf_in.read())

        out_file = out_dir / target_name
        out_file.parent.mkdir(parents=True, exist_ok=True)
        out_file.write_text(contents)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v0/sequencer_connection.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v0/sequencer_connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@com/digitalasset/canton/domain/api/v0/sequencer_connection.proto\x12%com.digitalasset.canton.domain.api.v0\x1a\x1egoogle/protobuf/wrappers.proto\"\xba\x02\n\x13SequencerConnection\x12U\n\x04grpc\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.domain.api.v0.SequencerConnection.GrpcH\x00R\x04grpc\x12\x14\n\x05\x61lias\x18\x03 \x01(\tR\x05\x61lias\x1a\xad\x01\n\x04Grpc\x12 \n\x0b\x63onnections\x18\x01 \x03(\tR\x0b\x63onnections\x12,\n\x11transportSecurity\x18\x02 \x01(\x08R\x11transportSecurity\x12U\n\x17\x63ustomTrustCertificates\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValueR\x17\x63ustomTrustCertificatesB\x06\n\x04type*\x1c\n\x10SequencerApiType\x12\x08\n\x04Grpc\x10\x00\x42VZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v0.sequencer_connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0'
  _globals['_SEQUENCERAPITYPE']._serialized_start=456
  _globals['_SEQUENCERAPITYPE']._serialized_end=484
  _globals['_SEQUENCERCONNECTION']._serialized_start=140
  _globals['_SEQUENCERCONNECTION']._serialized_end=454
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_start=273
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_end=446
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import base64
from dataclasses import dataclass
from pathlib import Path
import sys
from typing import Optional
from urllib import request

from rich.console import Console
from rich.progress import Progress

if sys.version_info >= (3, 11):
    from typing import Self
else:
    from typing_extensions import Self

__all__ = ["download_dependencies"]


@dataclass(frozen=True)
class Source:
    file_name: str
    url: str

    @classmethod
    def canton_2(cls, version: str) -> Self:
        file_name = f"canton-open-source-{version}.zip"
        url = f"https://github.com/digital-asset/canton/releases/download/v{version}/{file_name}"
        return cls(url=url, file_name=file_name)

    @classmethod
    def daml_protos(cls, version: str) -> Self:
        file_name = f"protobufs-{version}.zip"
        if "snapshot" in version:
            # snapshot versions are unfortunately not discoverable by version number alone
            # TODO: might be time to retire this machinery and start pulling down files a different way
            url = "https://github.com/digital-asset/daml/releases/download/v3.2.0-snapshot.20241106.0/protobufs-3.2.0-snapshot.20241031.13398.0.vf95d2607.zip"
        else:
            url = f"https://github.com/digital-asset/daml/releases/download/v{version}/{file_name}"
        return cls(url=url, file_name=file_name)

    def existing_file_md5(self, to: Path) -> Optional[bytes]:
        import hashlib

        path = to / self.file_name
        if path.exists() and path.is_file():
            md5_hash = hashlib.md5()
            with path.open("rb") as f:
                while chunk := f.read(4096):
                    md5_hash.update(chunk)
            return md5_hash.digest()
        else:
            return None

    def remote_md5(self) -> Optional[bytes]:
        """
        Make a HEAD request for this Source's data, and retrieve its MD5.
        """
        response = request.urlopen(request.Request(self.url, method="HEAD"))
        try:
            if response.code == 200:
                md5_base64 = response.headers["Content-MD5"]
                return base64.b64decode(md5_base64) if md5_base64 is not None else None
            else:
                raise RuntimeError(f"when trying to fetch {self.url}, got a {response.code}")
        finally:
            response.close()


@dataclass(frozen=True)
class DownloadPaths:
    canton_2_zip: Path
    daml_2_protos_zip: Path
    daml_3_protos_zip: Path


class Downloader:
    def __init__(self, source: Source, output_path: Path):
        self.source = source
        self.output_path = output_path

    def download(self, progress: Progress) -> None:
        self.output_path.parent.mkdir(parents=True, exist_ok=True)
        with request.urlopen(self.source.url) as response:
            task = progress.add_task("[cyan]" + self.source.file_name, total=response.length)
            with self.output_path.open("wb") as file:
                while chunk := response.read(4096):
                    file.write(chunk)
                    progress.update(task, advance=len(chunk))


def download_dependencies(
    daml_2_sdk_version: str, daml_3_sdk_version: str, to: Path
) -> DownloadPaths:
    canton_2 = Source.canton_2(daml_2_sdk_version)
    daml_2_protos = Source.daml_protos(daml_2_sdk_version)
    daml_3_protos = Source.daml_protos(daml_3_sdk_version)

    paths = DownloadPaths(
        canton_2_zip=to / canton_2.file_name,
        daml_2_protos_zip=to / daml_2_protos.file_name,
        daml_3_protos_zip=to / daml_3_protos.file_name,
    )

    downloaders = [
        Downloader(canton_2, paths.canton_2_zip),
        Downloader(daml_2_protos, paths.daml_2_protos_zip),
        Downloader(daml_3_protos, paths.daml_3_protos_zip),
    ]

    console = Console()
    console.print("[yellow]Downloading dependencies...")

    for downloader in downloaders:
        if existing_hash := downloader.source.existing_file_md5(to):
            actual_hash = downloader.source.remote_md5()
            if actual_hash is None:
                console.print(
                    f"    [yellow]{downloader.source.file_name} exists, but the remote did not return an MD5 hash; assuming the local file is good..."
                )
                continue
            if existing_hash == actual_hash:
                console.print(f"    [green]{downloader.source.file_name} already cached")
                continue
            else:
                console.print(
                    f"    [red]{downloader.source.file_name} exists, but failed MD5 check"
                )
        else:
            console.print(f"    [yellow]{downloader.source.file_name} downloading...")

        with Progress() as progress:
            downloader.download(progress)

    return paths



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....pruning.admin.v0 import pruning_pb2 as _pruning_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PruneRequest(_message.Message):
    __slots__ = ("prune_up_to",)
    PRUNE_UP_TO_FIELD_NUMBER: _ClassVar[int]
    prune_up_to: str
    def __init__(self, prune_up_to: _Optional[str] = ...) -> None: ...

class PruneResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSafePruningOffsetRequest(_message.Message):
    __slots__ = ("before_or_at", "ledger_end")
    BEFORE_OR_AT_FIELD_NUMBER: _ClassVar[int]
    LEDGER_END_FIELD_NUMBER: _ClassVar[int]
    before_or_at: _timestamp_pb2.Timestamp
    ledger_end: str
    def __init__(self, before_or_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ledger_end: _Optional[str] = ...) -> None: ...

class GetSafePruningOffsetResponse(_message.Message):
    __slots__ = ("safe_pruning_offset", "no_safe_pruning_offset")
    class NoSafePruningOffset(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    SAFE_PRUNING_OFFSET_FIELD_NUMBER: _ClassVar[int]
    NO_SAFE_PRUNING_OFFSET_FIELD_NUMBER: _ClassVar[int]
    safe_pruning_offset: str
    no_safe_pruning_offset: GetSafePruningOffsetResponse.NoSafePruningOffset
    def __init__(self, safe_pruning_offset: _Optional[str] = ..., no_safe_pruning_offset: _Optional[_Union[GetSafePruningOffsetResponse.NoSafePruningOffset, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .mediator_administration_service_pb2 import MediatorPruning
from .mediator_administration_service_pb2_grpc import MediatorAdministrationServiceStub
from .mediator_initialization_service_pb2 import InitializeMediatorRequest, InitializeMediatorResponse
from .mediator_initialization_service_pb2_grpc import MediatorInitializationServiceStub
from .sequencer_connection_service_pb2 import GetConnectionRequest, GetConnectionResponse, SetConnectionRequest, SetConnectionResponse
from .sequencer_connection_service_pb2_grpc import SequencerConnectionServiceStub

__all__ = [
    "GetConnectionRequest",
    "GetConnectionResponse",
    "InitializeMediatorRequest",
    "InitializeMediatorResponse",
    "MediatorAdministrationServiceStub",
    "MediatorInitializationServiceStub",
    "MediatorPruning",
    "SequencerConnectionServiceStub",
    "SetConnectionRequest",
    "SetConnectionResponse",
]
